#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""Custom format log"""

# System modules
import sys
from loguru import logger
from astropy.time import Time

# Custom modules
from directory.structure import log_path
from config.constants import log_ext

def mylog(date):
    "logger function"

    logger.remove()

    time = "{time:YYYY-MM-DD HH:mm:ss.SSS} "
    level = "<level>{level: <8}</level> "
    message = "| {message} "
    stack = "<bold>({module} {function}:{line})</bold>"
    fmt = time+level+message+stack

    # On standard output
    logger.add(sys.stderr, format=fmt)

    # logfile = log_path("{time:YYYY-MM-DD}.log")
    logfile = log_path(date.iso.split()[0]+log_ext)
    logger.add(logfile, format=fmt, colorize=True)

    logger.level("DEBUG", color="<magenta><bold>")
    logger.level("INFO", color="<green><bold>")

    return logger


def main():
    """Main function"""

    now = Time.now()
    log = mylog(now)

    log.debug("debug message")
    log.info("info message")
    log.warning("warning message")
    log.error("error message")
    log.critical("critical message")


def log_prefix(func):
    def inner_function(*args, **kwargs):
        # add a prefix based on used Template name
        return func(*args, **kwargs)
    return inner_function


if __name__ == "__main__":
    main()
else:
    now = Time.now()
    log = mylog(now)
